##  Authentication
You authenticate to the AI Agent API using an API token created in SAP LeanIX. To learn more about authentication, see [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US "https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US").
